<?php
/**
 * Template part for displaying front page blog section.
 *
 * @package Moral
 */

// Get default  mods value.
$blog_section = get_theme_mod( 'franchise_blog_section', 'recent-posts' );

if ( 'disable' === $blog_section ) {
	return;
}

$default = franchise_get_default_mods();

$img_position = get_theme_mod( 'franchise_blog_image_position', 'before-title' );

?>

<div id="latest-news" class="relative page-section">
    <div class="wrapper">
        <div class="section-header clear">
        	<?php  
        	$section_title =  get_theme_mod( 'franchise_blog_section_title', $default['franchise_blog_section_title'] );
        	$section_sub_title =  get_theme_mod( 'franchise_blog_section_sub_title', $default['franchise_blog_section_sub_title'] );
        	if ( ! empty( $section_sub_title ) ) : ?>
            	<span class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></span>
        	<?php endif;
        	if ( ! empty( $section_title ) ) : ?>
            	<h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
        	<?php endif; ?>
        </div><!-- .section-header -->

        <!-- supports col-1, col-2, col-3, col-4 -->
        <?php  
        $posts_per_page = get_theme_mod( 'franchise_blog_section_num', 3 );
        if ( $posts_per_page > 3 ) {
        	$class = 3;
        } else {
        	$class = $posts_per_page; 
        }
        ?>
        <div class="blog-posts-wrapper col-<?php echo esc_attr( $class ); ?>">
        	<?php  
        	if ( 'recent-posts' === $blog_section ) {
            	$args = array(
            			'posts_per_page' => $posts_per_page,
            			'ignore_sticky_posts' => true,
            		);
        	} elseif ( 'cat' === $blog_section ) {
        		$cat_id = get_theme_mod( 'franchise_blog_section_cat' );
        		$args = array(
            			'posts_per_page' => $posts_per_page,
            			'ignore_sticky_posts' => true,
            			'cat' => $cat_id,
            		);
        	} elseif ( 'post' === $blog_section ) {
        		$id = array();
				for ( $i=1; $i <= $posts_per_page; $i++ ) { 
					$id[] = get_theme_mod( 'franchise_blog_section_post_' . $i );
				}
        		$args = array(
            			'posts_per_page' => $posts_per_page,
            			'ignore_sticky_posts' => true,
						'post__in' => (array)$id,	
    					'orderby'	=> 'post__in',
            		);
        	}

        	$query = new WP_Query( $args );

			if ( $query->have_posts() ) :
				while ( $query->have_posts() ) :
					$query->the_post(); 

						$img_html = 
						'<div class="featured-image" style="background-image: url('. esc_url( get_the_post_thumbnail_url( get_the_ID(), 'large' ) ) . ');">';
							if ( has_post_thumbnail() ) {
	                        	$img_html .= '<a href="' . esc_url( get_permalink() ) . '" class="featured-image-link"></a>';
							}
	                        $img_html .= '<div class="entry-meta">
	                            <span class="byline">' . esc_html__( 'by : ', 'franchise-pro' ) .'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span></span>
	                            '. franchise_posted_on( false ) . '
	                        </div><!-- .entry-meta -->
	                    </div><!-- .featured-image -->';

						$class = ( has_post_thumbnail() ) ? 'has-post-thumbnail' : '';
						?>
		                <article class="animated animatedFadeInUp <?php echo esc_attr( $class );?>">
		                    
		                    <?php
		                    if ( 'before-title' === $img_position ) {
		                    	echo $img_html;
		                    }
		                    ?>

		                    <div class="entry-container">
		                        <div class="entry-meta">
		                            <span class="cat-links">
		                                <?php the_category( esc_html__( ', ', 'franchise-pro' ) ); ?>
		                            </span><!-- .cat-links -->
		                        </div><!-- .entry-meta -->

		                        <header class="entry-header">
		                            <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title();?></a></h2>
		                        </header>
		                        <?php
			                    if ( 'after-title' === $img_position ) {
			                    	echo $img_html;
			                    }
			                    ?>
		                        <div class="entry-content">
		                            <?php the_excerpt(); ?>
		                        </div><!-- .entry-content -->
		                    </div><!-- .entry-container -->
		                </article>
		        <?php endwhile; ?>
		        <?php wp_reset_postdata(); ?>
        	<?php endif; ?>
        </div><!-- .blog-posts-wrapper -->

        <div class="section-separator"></div>
    </div><!-- .wrapper -->
</div><!-- #latest-posts -->