<?php
/**
 * Template part for displaying front page projects.
 *
 * @package Moral
 */

// Get default  mods value.
$projects = get_theme_mod( 'franchise_projects', 'custom' );

if ( 'disable' === $projects ) {
	return;
}

$default = franchise_get_default_mods();
$section_title = get_theme_mod( 'franchise_projects_title', $default['franchise_projects_title'] );
$section_sub_title = get_theme_mod( 'franchise_projects_sub_title', $default['franchise_projects_sub_title'] );

?>
<div id="projects-section" class="relative page-section">
    <div class="wrapper">
        <div class="section-header clear">
            <span class="section-subtitle"><?php echo esc_html( $section_sub_title ); ?></span>
            <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
        </div><!-- .section-header -->

        <div class="projects-wrapper grid">
				<?php
				$projects_num = get_theme_mod( 'franchise_projects_num', 6 );

				if (  in_array( $projects, array( 'post', 'page', 'cat' ) ) ) {

					if ( 'cat' === $projects ) {
						$cat_id = get_theme_mod( 'franchise_projects_cat' );
						$args = array(
							'cat' => $cat_id,	
							'posts_per_page' => absint( $projects_num ),
						);
					} else {
						$id_arr = array();
						for ( $i=1; $i <= $projects_num; $i++ ) { 
							$id = get_theme_mod( "franchise_projects_{$projects}_" . $i );
							if ( $id ) {
								$id_arr[] = $id;
							}
						}
						$args = array(
							'post_type' => $projects,
							'post__in' => (array)$id_arr,	
							'posts_per_page' => asbint( $projects_num ),
                            'orderby'   => 'post__in',
							'ignore_sticky_posts' => true,
						);
					}

					$query = new WP_Query( $args );

					if ( $query->have_posts() ) {
						while ( $query->have_posts() ) {
							$query->the_post();
							?>

				            <article class="grid-item animated animatedFadeInUp">
				            	<?php if ( has_post_thumbnail() ) : ?>
					                <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url( 'large' ); ?>');">
					                    <a href="<?php the_permalink(); ?>" class="more-link">
					                    	<?php echo franchise_get_svg( array( 'icon' => 'arrow-right' ) ); ?>
					                    </a>
					                </div><!-- .featured-image -->
				            	<?php endif; ?>

				                <div class="entry-container">
				                    <header class="entry-header">
				                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
				                    </header>
				                    <div class="entry-meta">
				                        <span class="cat-links"><?php the_category( esc_html__( ' / ', 'franchise-pro' ) ); ?></span>
				                        
				                    </div><!-- .entry-meta -->
				                </div><!-- .entry-container -->
				            </article>

						<?php	
						}
						wp_reset_postdata();
					}
				} else {
					for ( $i=1; $i <= $projects_num; $i++ ) { 
						$title   = get_theme_mod( 'franchise_projects_custom_title_' . $i, $default['franchise_projects_custom_title'] );
						$type   = get_theme_mod( 'franchise_projects_custom_type_' . $i, $default['franchise_projects_custom_type'] );
						$url   = get_theme_mod( 'franchise_projects_link_' . $i, '#' );
						$img_url   = get_theme_mod( 'franchise_projects_image_' . $i );
						?>
						<article class="grid-item animated animatedFadeInUp">
			            	<?php if ( ! empty( $img_url ) ) : ?>
				                <div class="featured-image" style="background-image: url('<?php echo esc_url( $img_url ); ?>');">
				                    <a href="<?php echo esc_url( $url ); ?>" class="more-link">
					                    <?php echo franchise_get_svg( array( 'icon' => 'arrow-right' ) ); ?>
				                    </a>
				                </div><!-- .featured-image -->
			            	<?php endif; ?>

			                <div class="entry-container">
			                    <header class="entry-header">
			                        <h2 class="entry-title"><a href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $title ); ?></a></h2>
			                    </header>
			                    <div class="entry-meta">
			                        <span class="cat-links"><?php echo esc_html( $type ); ?></span>
			                        
			                    </div><!-- .entry-meta -->
			                </div><!-- .entry-container -->
			            </article>
						<?php	
					}
				}
				?>
            </div><!-- .grid -->
    </div><!-- .wrapper -->
</div><!-- #projects-section -->