<?php
/**
 * Template part for displaying front page services.
 *
 * @package Moral
 */

// Get default  mods value.
$services = get_theme_mod( 'franchise_services', 'custom' );

if ( 'disable' === $services ) {
    return;
}

$default = franchise_get_default_mods();

$services_num = get_theme_mod( 'franchise_services_num', 3 );

$col_class = '';
if ( $services_num > 4 ) {
    if ( $services_num % 3 === 0 ) {
        $col_class = 3;
    } else {
        $col_class = 4;
    }
} else {
    $col_class = $services_num;
}

$img_postion = get_theme_mod( 'franchise_services_image_position', 'after-content' );

?>
<div id="services-section" class="relative page-section">
    <div class="wrapper">
        <div class="services-items-wrapper col-<?php echo esc_attr( $col_class ); ?>">
                <?php

                if (  in_array( $services, array( 'post', 'page', 'cat' ) ) ) {

                    if ( 'cat' === $services ) {
                        $cat_id = get_theme_mod( 'franchise_services_cat' );
                        $args = array(
                            'cat' => $cat_id,   
                            'posts_per_page' =>  absint( $services_num ),
                        );
                    } else {
                        $id = array();
                        for ( $i=1; $i <= $services_num; $i++ ) { 
                            $id[] = get_theme_mod( "franchise_services_{$services}_" . $i );
                        }
                        $args = array(
                            'post_type' => $services,
                            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
                            'posts_per_page' => absint( $services_num ),
                            'ignore_sticky_posts' => true,
                        );
                    }

                    $query = new WP_Query( $args );

                    $i = 1;
                    if ( $query->have_posts() ) :
                        while ( $query->have_posts() ) :
                            $query->the_post();
                            
                            $img_html = '';
                            if ( has_post_thumbnail() ) : 
                                $img_html =
                                '<div class="featured-image" style="background-image: url(' . esc_url( get_the_post_thumbnail_url( get_the_ID(), 'large' ) ) . ');">
                                    <a href="' . esc_url( get_permalink() ) . '" class="featured-image-link"></a>
                                </div><!-- .featured-image -->';
                            endif;
                            ?>
                            
                            <article class="animated animatedFadeInUp">
                                <header class="entry-header">
                                    <span class="entry-subtitle"><?php echo esc_html( get_theme_mod( 'franchise_services_custom_sub_title_' . $i, $default['franchise_services_custom_sub_title'] ) ); ?></span>
                                    <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                </header>

                                <?php 
                                if ( 'after-title' === $img_postion ) {
                                    echo $img_html; 
                                }
                                ?>

                                <div class="entry-content">
                                    <?php the_excerpt();?>
                                </div><!-- .entry-content -->

                                <?php 
                                if ( 'after-content' === $img_postion ) {
                                    echo $img_html; 
                                }
                                ?>

                            </article>

                        <?php 
                        $i++;
                        endwhile;
                        wp_reset_postdata();
                    endif; 
                } else {
                    for ( $i=1; $i <= $services_num; $i++ ) { 
                        $title   = get_theme_mod( 'franchise_services_custom_title_' . $i, $default['franchise_services_custom_title'] );
                        $sub_title   = get_theme_mod( 'franchise_services_custom_sub_title_' . $i, $default['franchise_services_custom_sub_title'] );
                        $excerpt   = get_theme_mod( 'franchise_services_custom_content_' . $i, $default['franchise_services_custom_content'] );
                        $url   = get_theme_mod( 'franchise_services_link_' . $i, '#' );
                        $img_url   = get_theme_mod( 'franchise_services_image_' . $i );

                        $img_html = '';
                        if ( ! empty( $img_url ) ) :
                            $img_html = 
                            '<div class="featured-image" style="background-image: url(' . esc_url( $img_url ) . ');">
                                <a href="' . esc_url( $url ) . '" class="featured-image-link"></a>
                            </div><!-- .featured-image -->';
                        endif;
                        ?>
                        <article class="animated animatedFadeInUp">
                            <header class="entry-header">
                                <span class="entry-subtitle"><?php echo esc_html( $sub_title ); ?></span>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $url ); ?>"><?php echo esc_html( $title ); ?></a></h2>
                            </header>
                            
                            <?php 
                            if ( 'after-title' === $img_postion ) {
                                echo $img_html; 
                            }
                            ?>

                            <div class="entry-content">
                                <p><?php echo esc_html( $excerpt ); ?></p>
                            </div><!-- .entry-content -->

                            <?php 
                            if ( 'after-content' === $img_postion ) {
                                echo $img_html; 
                            }
                            ?>

                        </article>
                <?php   
                    }
                }
                ?>
        </div><!-- .services-items-wrapper -->
    </div><!-- .wrapper -->
</div><!-- #services-section -->