<?php
/**
 * Template part for displaying front page testimonial.
 *
 * @package Moral
 */

// Get default  mods value.
$testimonial = get_theme_mod( 'franchise_testimonial', 'custom' );

if ( 'disable' === $testimonial ) {
    return;
}

$default = franchise_get_default_mods();

$testimonial_num = get_theme_mod( 'franchise_testimonial_num', 3 );

$img_position = get_theme_mod( 'franchise_testimonials_img_position', 'left' );

$section_class = ( 'left' === $img_position ) ? 'img-left' : 'img-right' ;
?>
<div id="testimonial-section" class="relative page-section <?php echo esc_attr( $section_class );?>">
    <div class="wrapper">
        <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":false, "autoplay": true, "fade": true }'>
	        	<?php

	        	if (  in_array( $testimonial, array( 'post', 'page', 'cat' ) ) ) {

	        	    if ( 'cat' === $testimonial ) {
	        	        $cat_id = get_theme_mod( 'franchise_testimonial_cat' );
	        	        $args = array(
	        	            'cat' => $cat_id,   
	        	            'posts_per_page' => absint( $testimonial_num ),
	        	        );
	        	    } else {
	        	        $id = array();
	        	        for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	        	            $id[] = get_theme_mod( "franchise_testimonial_{$testimonial}_" . $i );
	        	        }
	        	        $args = array(
	        	            'post_type' => $testimonial,
	        	            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
	        	            'posts_per_page' => absint( $testimonial_num ),
	        	            'ignore_sticky_posts' => true,
	        	        );
	        	    }

	        	    $query = new WP_Query( $args );
	        	    $i = 1;
	        	    if ( $query->have_posts() ) :
	        	        while ( $query->have_posts() ) :
	        	            $query->the_post();

	        	            $class = ( has_post_thumbnail() ) ? 'has-featured-image' : '';
	        	            ?>
	        	        	
	        	        	<article class="animated animatedFadeInUp <?php echo esc_attr( $class ); ?>">
	        	        		<div class="testimonial-item">
		        	            	<?php if ( has_post_thumbnail() ) { ?>
			        	        	    <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url( 'large' );?>');">
			        	        	        <a href="<?php the_permalink();?>" class="featured-image-link"></a>
			        	        	    </div><!-- .featured-image -->
		        	            	<?php } ?>

		        	        	    <div class="entry-container">
		        	        	        <header class="entry-header">
		        	        	            <h2 class="entry-title"><?php the_title();?></h2>
		        	        	            <span class="entry-subtitle"><?php echo esc_html( get_theme_mod( 'franchise_testimonial_custom_sub_title_' . $i, $default['franchise_testimonial_custom_sub_title'] ) ); ?></span>
		        	        	        </header>

		        	        	        <div class="entry-content">
		        	        	            <?php the_excerpt();?>
		        	        	        </div><!-- .entry-content -->
		        	        	    </div><!-- .entry-container -->
	        	        		</div>
	        	        	</article>
	        	        <?php 
	        	        $i++;
	        	    	endwhile;
	        	        wp_reset_postdata();
	        	    endif; 
	        	} else {
	        	    for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	        	        $title   = get_theme_mod( 'franchise_testimonial_custom_name_' . $i, $default['franchise_testimonial_custom_name'] );
	        	        $sub_title   = get_theme_mod( 'franchise_testimonial_custom_sub_title_' . $i, $default['franchise_testimonial_custom_sub_title'] );
	        	        $excerpt   = get_theme_mod( 'franchise_testimonial_custom_content_' . $i, $default['franchise_testimonial_custom_content'] );

	        	        $img_url = get_theme_mod( 'franchise_testimonial_image_' . $i );
	        	        
	        	        $class = ( ! empty( $img_url ) ) ? 'has-featured-image' : '';

	        	        ?>
	        	        <article class="animated animatedFadeInUp <?php echo esc_attr( $class ); ?>">
	        	        	<div class="testimonial-item">
	        	            	<?php if ( ! empty( $img_url ) ) { ?>
		        	        	    <div class="featured-image" style="background-image: url('<?php echo esc_url( $img_url );?>');">
		        	        	        <a href="" class="featured-image-link"></a>
		        	        	    </div><!-- .featured-image -->
	        	            	<?php } ?>

	        	        	    <div class="entry-container">
	        	        	        <header class="entry-header">
	        	        	            <h2 class="entry-title"><?php echo esc_html( $title );?></h2>
	        	        	            <span class="entry-subtitle"><?php echo esc_html( $sub_title );?></span>
	        	        	        </header>

	        	        	        <div class="entry-content">
	        	        	            <p><?php echo wp_kses_post( $excerpt );?></p>
	        	        	        </div><!-- .entry-content -->
	        	        	    </div><!-- .entry-container -->
	        	        	</div>
        	        	</article>
	        	<?php   
	        	    }
	        	}
	        	?>
		</div><!-- .testimonial-slider -->
    </div><!-- .wrapper -->
</div><!-- #testimonial-section -->