<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 */

/**
 * Get all the default values of the theme mods.
 */
function franchise_get_default_mods() {
	$franchise_default_mods = array(
		// About
		'franchise_about_title' => esc_html__( 'Design is the silent ambassador of your brand.', 'franchise-pro' ),
		'franchise_about_sub_title' => esc_html__( 'Who we are', 'franchise-pro' ),
		'franchise_about_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur placerat neque rhoncus, porta arcu quis, accumsan mi. Fusce a risus ut odio aliquet porta. Quisque laoreet tristique turpis sit amet dictum. Proin nec mauris sodales, sollicitudin nunc ut, hendrerit nulla. Nunc feugiat vulputate massa, non pharetra tellus fermentum eu. Nam in quam pellentesque, elementum enim quis, dapibus mi. Vivamus at pulvinar neque. ', 'franchise-pro' ),
		'franchise_about_btn_txt' => esc_html__( 'Know More', 'franchise-pro' ),
		
		// Projects
		'franchise_projects_custom_type' => esc_html__( 'Design / Minimal', 'franchise-pro' ),
		'franchise_projects_custom_title' => esc_html__( 'Wooden Texture', 'franchise-pro' ),
		'franchise_projects_title' => esc_html__( 'Our Projects', 'franchise-pro' ),
		'franchise_projects_sub_title' => esc_html__( 'Buy things. Get happy.', 'franchise-pro' ),

		// Services
		'franchise_services_custom_content' => esc_html__( 'Proin sodales nisi quam, eget commodo quam tempor cursus. Quisque libero quam', 'franchise-pro' ),
		'franchise_services_custom_title' => esc_html__( 'Clean and minimal web designing', 'franchise-pro' ),
		'franchise_services_custom_sub_title' => esc_html__( '01 Service', 'franchise-pro' ),

		// Testimonials
		'franchise_testimonial_custom_content' => esc_html__( '"Donec vehicula lacus ornare libero molestie, et pharetra neque sodales. Phasellus porttitor dapibus nulla. Suspendisse laoreet felis vitae tortor eleifend, ac cursus quam tempor."', 'franchise-pro' ),
		'franchise_testimonial_custom_name' => esc_html__( 'Federica Corneli', 'franchise-pro' ),
		'franchise_testimonial_custom_sub_title' => esc_html__( 'New York, U.S.A', 'franchise-pro' ),

		// Sliders
		'franchise_slider_custom_content' => esc_html__( 'We carve design in most  possible beautiful way.', 'franchise-pro' ),
		'franchise_slider_custom_btn' => esc_html__( 'Know More', 'franchise-pro' ),

		// Blog section
		'franchise_blog_section_title' => esc_html__( 'Stay Updated. Happening Now.', 'franchise-pro' ),
		'franchise_blog_section_sub_title' => esc_html__( 'Latest Blog', 'franchise-pro' ),

		// Footer copyright
		'franchise_copyright_txt' => sprintf( esc_html__( 'Theme: %1$s by %2$s.', 'franchise-pro' ), 'Franchise Pro', '<a href="' . esc_url( 'http://moralthemes.com/' ) . '">Moral Themes</a>' ),

		// Homepage sortable sections
		'franchise_sort_home_sections' => array( 'slider', 'about', 'services', 'projects', 'testimonials', 'partners', 'latest-posts' ),
	);

	return apply_filters( 'franchise_default_mods', $franchise_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function franchise_customize_register( $wp_customize ) {
	/**
	 * Separator custom control
	 *
	 * @version 1.0.0
	 * @since  1.0.0
	 */
	class Franchise_Separator_Custom_Control extends WP_Customize_Control {
		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'franchise-separator';
		/**
		 * Control method
		 *
		 * @since 1.0.0
		 */
		public function render_content() {
			?>
			<p><hr style="border-color: #222; opacity: 0.2;"></p>
			<?php
		}
	}

	/**
	 * The radio image customize control extends the WP_Customize_Control class.  This class allows
	 * developers to create a list of image radio inputs.
	 *
	 * Note, the `$choices` array is slightly different than normal and should be in the form of
	 * `array(
		 *	$value => array( 'color' => $color_value ),
		 *	$value => array( 'color' => $color_value ),
	 * )`
	 *
	 */

	/**
	 * Radio color customize control.
	 *
	 * @since  3.0.0
	 * @access public
	 */
	class Franchise_Customize_Control_Radio_Color extends WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 *
		 * @since  3.0.0
		 * @access public
		 * @var    string
		 */
		public $type = 'radio-color';

		/**
		 * Add custom parameters to pass to the JS via JSON.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function to_json() {
			parent::to_json();

			// We need to make sure we have the correct color URL.
			foreach ( $this->choices as $value => $args )
				$this->choices[ $value ]['color'] = esc_attr( $args['color'] );

			$this->json['choices'] = $this->choices;
			$this->json['link']    = $this->get_link();
			$this->json['value']   = $this->value();
			$this->json['id']      = $this->id;
		}

		/**
		 * Don't render the content via PHP.  This control is handled with a JS template.
		 *
		 * @since  4.0.0
		 * @access public
		 * @return bool
		 */
		protected function render_content() {}

		/**
		 * Underscore JS template to handle the control's output.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function content_template() { ?>

			<# if ( ! data.choices ) {
				return;
			} #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

			<# _.each( data.choices, function( args, choice ) { #>
				<label>
					<input type="radio" value="{{ choice }}" name="_customize-{{ data.type }}-{{ data.id }}" {{{ data.link }}} <# if ( choice === data.value ) { #> checked="checked" <# } #> />

					<span class="screen-reader-text">{{ args.label }}</span>
					
					<# if ( 'custom' != choice ) { #>
						<span class="color-value" style="background-color: {{ args.color }}"></span>
					<# } else { #>
						<span class="color-value custom-color-value"></span>
					<# } #>
				</label>
			<# } ) #>
		<?php }
	}

	$wp_customize->register_control_type( 'Franchise_Customize_Control_Radio_Color'       );

	class Franchise_Customize_Control_Sort_Sections extends WP_Customize_Control {

	  	/**
	   	* Control Type
	   	*/
	  	public $type = 'sortable';
	  
		/**
		* Add custom parameters to pass to the JS via JSON.
		*
		* @access public
		* @return void
		*/
	  	public function to_json() {
		  	parent::to_json();

	    	$choices = $this->choices;
	      	$choices = array_filter( array_merge( array_flip( $this->value() ), $choices ) );
		  	$this->json['choices'] = $choices;
		  	$this->json['link']    = $this->get_link();
		  	$this->json['value']   = $this->value();
		  	$this->json['id']      = $this->id;
	  	}

	  	/**
	   	* Render Settings
	   	*/
	  	public function content_template() { ?>
		  	<# if ( ! data.choices ) {
		  		return;
		  	} #>

		    <# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

		    <# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

		    <ul class="franchise-sortable-list">

		      	<# _.each( data.choices, function( args, choice ) { #>

		        <li>
		            <input class="franchise-sortable-input sortable-hideme" name="{{choice}}" type="hidden"  value="{{ choice }}" />
		            <span class ="menu-item-handle sortable-span">{{args.name}}</span>
		          <i title="<?php esc_html_e( 'Drag and Move', 'franchise-pro' );?>" class="dashicons dashicons-menu franchise-drag-handle"></i>
		          <i title="<?php esc_html_e( 'Edit', 'franchise-pro' );?>" class="dashicons dashicons-edit franchise-edit" data-jump="{{args.section_id}}"></i>
		        </li>

		        <# } ) #>

		        <li class="sortable-hideme">
		          <input class="franchise-sortable-value" {{{ data.link }}} value="{{data.value}}" />
		        </li>

		    </ul>
	  	<?php
	  	}
	}

	$wp_customize->register_control_type( 'Franchise_Customize_Control_Sort_Sections' );

	$default = franchise_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'franchise_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'franchise_customize_partial_blogdescription',
		) );
	}

	/**
	 *
	 * 
	 * Header panel
	 *
	 * 
	 */
	// Header panel
	$wp_customize->add_panel(
		'franchise_header_panel',
		array(
			'title' => esc_html__( 'Header', 'franchise-pro' ),
			'priority' => 100
		)
	);

	$wp_customize->get_section( 'title_tagline' )->panel         = 'franchise_header_panel';

	// Header text display setting
	$wp_customize->add_setting(	
		'franchise_header_text_display',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'franchise-pro' ),
		)
	);

	// Header section
	$wp_customize->add_section(
		'franchise_header_section',
		array(
			'title' => esc_html__( 'Header', 'franchise-pro' ),
			'panel' => 'franchise_header_panel',
		)
	);

	// Header menu sticky enable settings
	$wp_customize->add_setting(
		'franchise_make_menu_sticky',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false
		)
	);

	$wp_customize->add_control(
		'franchise_make_menu_sticky',
		array(
			'section'		=> 'franchise_header_section',
			'label'			=> esc_html__( 'Make menu sticky.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Header search form settings
	$wp_customize->add_setting(
		'franchise_show_search',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'franchise_show_search',
		array(
			'section'		=> 'franchise_header_section',
			'label'			=> esc_html__( 'Show search.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Header alignment setting
	$wp_customize->add_setting(	
		'franchise_header_alignment',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control( 'franchise_header_alignment',
		array(
			'section'		=> 'franchise_header_section',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Align menu to center.', 'franchise-pro' ),
		)
	);

	// Menu type settings
	$wp_customize->add_setting(
		'franchise_menu_type',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'classic'
		)
	);

	$wp_customize->add_control(
		'franchise_menu_type',
		array(
			'section'		=> 'franchise_header_section',
			'label'			=> esc_html__( 'Primary menu type:', 'franchise-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
					'modern' => esc_html__( 'Modern', 'franchise-pro' ),
					'classic' => esc_html__( 'Classic', 'franchise-pro' ),
			 	)
		)
	);

	/**
	 *
	 * 
	 * Home sections panel
	 *
	 * 
	 */
	// Home sections panel
	$wp_customize->add_panel(
		'franchise_home_panel',
		array(
			'title' => esc_html__( 'Homepage', 'franchise-pro' ),
			'priority' => 105
		)
	);

	$wp_customize->get_section( 'static_front_page' )->panel         = 'franchise_home_panel';

	// Homepage sort section
	$wp_customize->add_section(
		'franchise_homepage_section_sort',
		array(
			'title' => esc_html__( 'Sort sections', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Homepage sections sortable.
	$wp_customize->add_setting(	
		'franchise_sort_home_sections',
		array(
			'sanitize_callback' => 'franchise_sanitize_sort',
			'default'	=> $default['franchise_sort_home_sections'],
		)
	);

	$wp_customize->add_control( 
		new Franchise_Customize_Control_Sort_Sections( 
		$wp_customize,
		'franchise_sort_home_sections',
			array(
				'section'		=> 'franchise_homepage_section_sort',
				'label'			=> esc_html__( 'Sort sections', 'franchise-pro' ),
				'choices'  => array(
		            'slider'    => array(
		            	'name' => esc_html__( 'Slider', 'franchise-pro' ),
		            	'section_id' => 'franchise_slider'
		            ), 
		            'about'    => array(
		            	'name' => esc_html__( 'About', 'franchise-pro' ),
		            	'section_id' => 'franchise_about'
		            ),
		            'services'    => array(
		            	'name' => esc_html__( 'Services', 'franchise-pro' ),
		            	'section_id' => 'franchise_services'
		            ), 
		            'projects'    => array(
		            	'name' => esc_html__( 'Projects', 'franchise-pro' ),
		            	'section_id' => 'franchise_projects'
		            ), 
		            'testimonials'    => array(
		            	'name' => esc_html__( 'Testimonial', 'franchise-pro' ),
		            	'section_id' => 'franchise_testimonial'
		            ), 
		            'partners'    => array(
		            	'name' => esc_html__( 'Partner', 'franchise-pro' ),
		            	'section_id' => 'franchise_partner'
		            ),
		            'latest-posts'    => array(
		            	'name' => esc_html__( 'Blog Section', 'franchise-pro' ),
		            	'section_id' => 'franchise_blog_section'
		            ), 
		        ),
			)
		)
	);

	// Your latest posts title setting
	$wp_customize->add_setting(	
		'franchise_your_latest_posts_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Blogs', 'franchise-pro' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_your_latest_posts_title',
		array(
			'section'		=> 'static_front_page',
			'label'			=> esc_html__( 'Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_is_latest_posts'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_your_latest_posts_title', 
		array(
	        'selector'            => '.home.blog #page-header .page-title',
			'render_callback'     => 'franchise_your_latest_posts_partial_title',
    	) 
    );

	/**
	 * Slider section
	 */
	// Slider section
	$wp_customize->add_section(
		'franchise_slider',
		array(
			'title' => esc_html__( 'Slider', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Slider enable settings
	$wp_customize->add_setting(
		'franchise_slider',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'franchise_slider',
		array(
			'section'		=> 'franchise_slider',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
					'post' => esc_html__( 'Post', 'franchise-pro' ),
					'page' => esc_html__( 'Page', 'franchise-pro' ),
					'cat' => esc_html__( 'Category', 'franchise-pro' ),
					'custom' => esc_html__( 'Custom', 'franchise-pro' ),
			 	)
		)
	);

	// Slider number setting
	$wp_customize->add_setting(
		'franchise_slider_num',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 3,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_slider_num',
		array(
			'section'		=> 'franchise_slider',
			'label'			=> esc_html__( 'Number of slider:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 9', 'franchise-pro' ),
			'active_callback' => 'franchise_if_slider_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 9 ),
		)
	);

	// Slider number separator setting
	$wp_customize->add_setting(
		'franchise_slider_num_separator',
		array(
			'sanitize_callback' => 'franchise_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Franchise_Separator_Custom_Control( 
		$wp_customize,
		'franchise_slider_num_separator',
			array(
				'section'		=> 'franchise_slider',
				'active_callback' => 'franchise_if_slider_not_disabled',
				'type'			=> 'franchise-separator',
			)
		)
	);

	// Slider category setting
	$wp_customize->add_setting(
		'franchise_slider_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'franchise_slider_cat',
		array(
			'section'		=> 'franchise_slider',
			'label'			=> esc_html__( 'Category:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_slider_cat',
			'type'			=> 'select',
			'choices'		=> franchise_get_post_cat_choices(),
		)
	);

	$slider_num = get_theme_mod( 'franchise_slider_num', 3 );
	for ( $i=1; $i <= $slider_num; $i++ ) { 
		// Slider custom image setting
		$wp_customize->add_setting(
			'franchise_slider_image_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_image',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'franchise_slider_image_' . $i,
				array(
					'section'		=> 'franchise_slider',
					'label'			=> esc_html__( 'Image ', 'franchise-pro' ) . $i,
					'active_callback' => 'franchise_if_slider_custom',
				)
			)
		);

	    // Slider custom content setting
		$wp_customize->add_setting(
			'franchise_slider_custom_content_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
				'default' => $default['franchise_slider_custom_content'],
			)
		);

		$wp_customize->add_control(
			'franchise_slider_custom_content_' . $i,
			array(
				'section'		=> 'franchise_slider',
				'label'			=> esc_html__( 'Content ', 'franchise-pro' ) . $i,
				'description'			=> esc_html__( 'HTML Allowed', 'franchise-pro' ),
				'active_callback' => 'franchise_if_slider_custom',
				'type'			=> 'textarea'
			)
		);

		// Slider custom name setting
		$wp_customize->add_setting(
			'franchise_slider_custom_btn_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_slider_custom_btn'],
			)
		);

		$wp_customize->add_control(
			'franchise_slider_custom_btn_' . $i,
			array(
				'section'		=> 'franchise_slider',
				'label'			=> esc_html__( 'Button text ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_slider_not_disabled'
			)
		);

		// Slider custom link setting
		$wp_customize->add_setting(
			'franchise_slider_custom_link_' . $i,
			array(
				'sanitize_callback' => 'esc_url_raw',
				'default' => '#',
			)
		);

		$wp_customize->add_control(
			'franchise_slider_custom_link_' . $i,
			array(
				'section'		=> 'franchise_slider',
				'label'			=> esc_html__( 'Button link ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_slider_custom',
				'type'			=> 'url'
			)
		);


		// Slider post setting
		$wp_customize->add_setting(
			'franchise_slider_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_slider_post_' . $i,
			array(
				'section'		=> 'franchise_slider',
				'label'			=> esc_html__( 'Post ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_slider_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);
		
		// Slider page setting
		$wp_customize->add_setting(
			'franchise_slider_page_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'franchise_slider_page_' . $i,
			array(
				'section'		=> 'franchise_slider',
				'label'			=> esc_html__( 'Page ', 'franchise-pro' ) . $i,
				'type'			=> 'dropdown-pages',
				'active_callback' => 'franchise_if_slider_page'
			)
		);
		
		// Slider custom separator setting
		$wp_customize->add_setting(
			'franchise_slider_custom_separator_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Franchise_Separator_Custom_Control( 
			$wp_customize,
			'franchise_slider_custom_separator_' . $i,
				array(
					'section'		=> 'franchise_slider',
					'active_callback' => 'franchise_if_slider_not_disabled',
					'type'			=> 'franchise-separator',
				)
			)
		);
	}

	/**
	 * About section
	 */
	// About section
	$wp_customize->add_section(
		'franchise_about',
		array(
			'title' => esc_html__( 'About', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// About enable settings
	$wp_customize->add_setting(
		'franchise_about',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'franchise_about',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
					'post' => esc_html__( 'Post', 'franchise-pro' ),
					'page' => esc_html__( 'Page', 'franchise-pro' ),
					'custom' => esc_html__( 'Custom', 'franchise-pro' ),
			 	)
		)
	);

	// About image position option.
	$wp_customize->add_setting(	
		'franchise_about_image_position',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'franchise_about_image_position',
		array(
			'section'		=> 'franchise_about',
			'type'			=> 'radio',
			'active_callback' => 'franchise_if_about_enabled',
			'label'			=> esc_html__( 'Image position', 'franchise-pro' ),
			'choices'		=> array( 
									'left' => esc_html__( 'Left', 'franchise-pro' ), 
									'right' => esc_html__( 'Right', 'franchise-pro' ), 
								),
		)
	);

	// About post setting
	$wp_customize->add_setting(
		'franchise_about_post',
		array(
			'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'franchise_about_post',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Post:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_about_post',
			'type'			=> 'select',
			'choices'		=> franchise_get_post_choices(),
		)
	);

	// About page setting
	$wp_customize->add_setting(
		'franchise_about_page',
		array(
			'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'franchise_about_page',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Page:', 'franchise-pro' ),
			'type'			=> 'dropdown-pages',
			'active_callback' => 'franchise_if_about_page'
		)
	);

	// About image setting
	$wp_customize->add_setting(
		'franchise_about_image',
		array(
			'sanitize_callback' => 'franchise_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'franchise_about_image',
			array(
				'section'		=> 'franchise_about',
				'label'			=> esc_html__( 'Image:', 'franchise-pro' ),
				'active_callback' => 'franchise_if_about_custom',
			)
		)
	);

	// About title setting
	$wp_customize->add_setting(
		'franchise_about_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_about_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_about_title',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_about_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_about_title', 
		array(
	        'selector'            => '#about-us .section-title',
			'render_callback'     => 'franchise_about_partial_title',
    	) 
    );

	// About sub title setting
	$wp_customize->add_setting(
		'franchise_about_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_about_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_about_sub_title',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Sub title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_about_enabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_about_sub_title', 
		array(
	        'selector'            => '#about-us .section-subtitle',
			'render_callback'     => 'franchise_about_partial_sub_title',
    	) 
    );

	// About content setting
	$wp_customize->add_setting(
		'franchise_about_content',
		array(
			'sanitize_callback' => 'sanitize_textarea_field',
			'default' => $default['franchise_about_content'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_about_content',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Content:', 'franchise-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'franchise_if_about_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_about_content', 
		array(
	        'selector'            => '#about-us .entry-content',
			'render_callback'     => 'franchise_about_partial_content',
    	) 
    );

	// About button text setting
	$wp_customize->add_setting(
		'franchise_about_btn_txt',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_about_btn_txt'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_about_btn_txt',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Button Text:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_about_enabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_about_btn_txt', 
		array(
	        'selector'            => '#about-us .more-link a',
			'render_callback'     => 'franchise_about_partial_btn_txt',
    	) 
    );

	// About link setting
	$wp_customize->add_setting(
		'franchise_about_link',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		)
	);

	$wp_customize->add_control(
		'franchise_about_link',
		array(
			'section'		=> 'franchise_about',
			'label'			=> esc_html__( 'Button Link:', 'franchise-pro' ),
			'type'			=> 'url',
			'active_callback' => 'franchise_if_about_custom'
		)
	);

	/**
	 * Services section
	 */
	// Services section
	$wp_customize->add_section(
		'franchise_services',
		array(
			'title' => esc_html__( 'Services', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Services enable settings
	$wp_customize->add_setting(
		'franchise_services',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'franchise_services',
		array(
			'section'		=> 'franchise_services',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
					'post' => esc_html__( 'Post', 'franchise-pro' ),
					'page' => esc_html__( 'Page', 'franchise-pro' ),
					'cat' => esc_html__( 'Category', 'franchise-pro' ),
					'custom' => esc_html__( 'Custom', 'franchise-pro' ),
			 	)
		)
	);

	// Services image position option.
	$wp_customize->add_setting(	
		'franchise_services_image_position',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'after-content',
		)
	);

	$wp_customize->add_control(
		'franchise_services_image_position',
		array(
			'section'		=> 'franchise_services',
			'type'			=> 'radio',
			'active_callback' => 'franchise_if_services_not_disabled',
			'label'			=> esc_html__( 'Image position', 'franchise-pro' ),
			'choices'		=> array( 
									'after-title' => esc_html__( 'After title', 'franchise-pro' ), 
									'after-content' => esc_html__( 'After content', 'franchise-pro' ), 
								),
		)
	);

    // Services number setting
	$wp_customize->add_setting(
		'franchise_services_num',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 3,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_services_num',
		array(
			'section'		=> 'franchise_services',
			'label'			=> esc_html__( 'Number of services:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 8', 'franchise-pro' ),
			'active_callback' => 'franchise_if_services_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 8 ),
		)
	);

	// Services number separator setting
	$wp_customize->add_setting(
		'franchise_services_num_separator',
		array(
			'sanitize_callback' => 'franchise_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Franchise_Separator_Custom_Control( 
		$wp_customize,
		'franchise_services_num_separator',
			array(
				'section'		=> 'franchise_services',
				'active_callback' => 'franchise_if_services_not_disabled',
				'type'			=> 'franchise-separator',
			)
		)
	);

    // Services category setting
	$wp_customize->add_setting(
		'franchise_services_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'franchise_services_cat',
		array(
			'section'		=> 'franchise_services',
			'label'			=> esc_html__( 'Category:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_services_cat',
			'type'			=> 'select',
			'choices'		=> franchise_get_post_cat_choices(),
		)
	);

	$services_num = get_theme_mod( 'franchise_services_num', 3 );
	for ( $i=1; $i <= $services_num; $i++ ) { 
		// Services custom title setting
		$wp_customize->add_setting(
			'franchise_services_custom_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_services_custom_title'],
			)
		);

		$wp_customize->add_control(
			'franchise_services_custom_title_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Title ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_services_custom'
			)
		);

		// Services custom sub title setting
		$wp_customize->add_setting(
			'franchise_services_custom_sub_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_services_custom_sub_title'],
			)
		);

		$wp_customize->add_control(
			'franchise_services_custom_sub_title_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Sub title ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_services_not_disabled'
			)
		);

	    // Services custom content setting
		$wp_customize->add_setting(
			'franchise_services_custom_content_' . $i,
			array(
				'sanitize_callback' => 'sanitize_textarea_field',
				'default' => $default['franchise_services_custom_content'],
			)
		);

		$wp_customize->add_control(
			'franchise_services_custom_content_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Content ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_services_custom',
				'type'			=> 'textarea'
			)
		);

		// Services custom image setting
		$wp_customize->add_setting(
			'franchise_services_image_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_image',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'franchise_services_image_' . $i,
				array(
					'section'		=> 'franchise_services',
					'label'			=> esc_html__( 'Image ', 'franchise-pro' ) . $i,
					'active_callback' => 'franchise_if_services_custom',
				)
			)
		);

		// Services custom link setting
		$wp_customize->add_setting(
			'franchise_services_link_' . $i,
			array(
				'sanitize_callback' => 'esc_url_raw',
				'default'		=> '#',
			)
		);

		$wp_customize->add_control(
			'franchise_services_link_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Link ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_services_custom',
				'type'			=> 'url',
			)
		);

		// Services post setting
		$wp_customize->add_setting(
			'franchise_services_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_services_post_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Post ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_services_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);

		// Services page setting
		$wp_customize->add_setting(
			'franchise_services_page_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'franchise_services_page_' . $i,
			array(
				'section'		=> 'franchise_services',
				'label'			=> esc_html__( 'Page ', 'franchise-pro' ) . $i,
				'type'			=> 'dropdown-pages',
				'active_callback' => 'franchise_if_services_page'
			)
		);

		// Services separator setting
		$wp_customize->add_setting(
			'franchise_services_separator_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Franchise_Separator_Custom_Control( 
			$wp_customize,
			'franchise_services_separator_' . $i,
				array(
					'section'		=> 'franchise_services',
					'active_callback' => 'franchise_if_services_not_disabled',
					'type'			=> 'franchise-separator',
				)
			)
		);
	}

	/**
	 * Projects section
	 */
	// Projects section
	$wp_customize->add_section(
		'franchise_projects',
		array(
			'title' => esc_html__( 'Projects', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Projects enable settings
	$wp_customize->add_setting(
		'franchise_projects',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'franchise_projects',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
					'post' => esc_html__( 'Post', 'franchise-pro' ),
					'page' => esc_html__( 'Page', 'franchise-pro' ),
					'cat' => esc_html__( 'Category', 'franchise-pro' ),
					'custom' => esc_html__( 'Custom', 'franchise-pro' ),
			 	)
		)
	);

	// Projects title setting
	$wp_customize->add_setting(
		'franchise_projects_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_projects_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_projects_title',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_projects_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_projects_title', 
		array(
	        'selector'            => '#projects-section .section-title',
			'render_callback'     => 'franchise_projects_partial_title',
    	) 
    );

    // Projects sub title setting
	$wp_customize->add_setting(
		'franchise_projects_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_projects_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_projects_sub_title',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Sub Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_projects_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_projects_sub_title', 
		array(
	        'selector'            => '#projects-section .section-subtitle',
			'render_callback'     => 'franchise_projects_partial_sub_title',
    	) 
    );

    // Projects number setting
	$wp_customize->add_setting(
		'franchise_projects_num',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 6,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_projects_num',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Number of projects:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Min: 3 | Max: 6', 'franchise-pro' ),
			'active_callback' => 'franchise_if_projects_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 3, 'max' => 6 ),
		)
	);

    // Projects category setting
	$wp_customize->add_setting(
		'franchise_projects_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'franchise_projects_cat',
		array(
			'section'		=> 'franchise_projects',
			'label'			=> esc_html__( 'Category:', 'franchise-pro' ),
			'description'			=> esc_html__( 'The button will be linked to the selected category\'s archive link automatically.', 'franchise-pro' ),
			'active_callback' => 'franchise_if_projects_cat',
			'type'			=> 'select',
			'choices'		=> franchise_get_post_cat_choices(),
		)
	);

	$projects_num = get_theme_mod( 'franchise_projects_num', 6 );
	for ( $i=1; $i <= $projects_num; $i++ ) { 
			// Projects custom title setting
		$wp_customize->add_setting(
			'franchise_projects_custom_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_projects_custom_title'],
			)
		);

		$wp_customize->add_control(
			'franchise_projects_custom_title_' . $i,
			array(
				'section'		=> 'franchise_projects',
				'label'			=> esc_html__( 'Title ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_projects_custom'
			)
		);

	    // Projects custom content setting
		$wp_customize->add_setting(
			'franchise_projects_custom_type_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_projects_custom_type'],
			)
		);

		$wp_customize->add_control(
			'franchise_projects_custom_type_' . $i,
			array(
				'section'		=> 'franchise_projects',
				'label'			=> esc_html__( 'Type ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_projects_custom',
			)
		);

		// Projects custom image setting
		$wp_customize->add_setting(
			'franchise_projects_image_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_image',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'franchise_projects_image_' . $i,
				array(
					'section'		=> 'franchise_projects',
					'label'			=> esc_html__( 'Image ', 'franchise-pro' ) . $i,
					'active_callback' => 'franchise_if_projects_custom',
				)
			)
		);

		// Projects custom link setting
		$wp_customize->add_setting(
			'franchise_projects_link_' . $i,
			array(
				'sanitize_callback' => 'esc_url_raw',
				'default'		=> '#',
			)
		);

		$wp_customize->add_control(
			'franchise_projects_link_' . $i,
			array(
				'section'		=> 'franchise_projects',
				'label'			=> esc_html__( 'Link ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_projects_custom',
				'type'			=> 'url',
			)
		);

		// Projects post setting
		$wp_customize->add_setting(
			'franchise_projects_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_projects_post_' . $i,
			array(
				'section'		=> 'franchise_projects',
				'label'			=> esc_html__( 'Post ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_projects_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);

		// Projects page setting
		$wp_customize->add_setting(
			'franchise_projects_page_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'franchise_projects_page_' . $i,
			array(
				'section'		=> 'franchise_projects',
				'label'			=> esc_html__( 'Page ', 'franchise-pro' ) . $i,
				'type'			=> 'dropdown-pages',
				'active_callback' => 'franchise_if_projects_page'
			)
		);

		// Projects custom separator setting
		$wp_customize->add_setting(
			'franchise_projects_custom_separator_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Franchise_Separator_Custom_Control( 
			$wp_customize,
			'franchise_projects_custom_separator_' . $i,
				array(
					'section'		=> 'franchise_projects',
					'active_callback' => 'franchise_if_projects_not_cat_disabled',
					'type'			=> 'franchise-separator',
				)
			)
		);
	}

	/**
	 * Testimonial section
	 */
	// Testimonial section
	$wp_customize->add_section(
		'franchise_testimonial',
		array(
			'title' => esc_html__( 'Testimonial', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Testimonial enable settings
	$wp_customize->add_setting(
		'franchise_testimonial',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'franchise_testimonial',
		array(
			'section'		=> 'franchise_testimonial',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
					'post' => esc_html__( 'Post', 'franchise-pro' ),
					'page' => esc_html__( 'Page', 'franchise-pro' ),
					'cat' => esc_html__( 'Category', 'franchise-pro' ),
					'custom' => esc_html__( 'Custom', 'franchise-pro' ),
			 	)
		)
	);

	// Testimonial image position option.
	$wp_customize->add_setting(	
		'franchise_testimonials_img_position',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'left',
		)
	);

	$wp_customize->add_control(
		'franchise_testimonials_img_position',
		array(
			'section'		=> 'franchise_testimonial',
			'type'			=> 'radio',
			'active_callback' => 'franchise_if_testimonial_not_disabled',
			'label'			=> esc_html__( 'Image position', 'franchise-pro' ),
			'choices'		=> array( 
									'left' => esc_html__( 'Left', 'franchise-pro' ), 
									'right' => esc_html__( 'Right', 'franchise-pro' ), 
								),
		)
	);

	// Testimonial number setting
	$wp_customize->add_setting(
		'franchise_testimonial_num',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 3,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_testimonial_num',
		array(
			'section'		=> 'franchise_testimonial',
			'label'			=> esc_html__( 'Number of testimonial:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 9', 'franchise-pro' ),
			'active_callback' => 'franchise_if_testimonial_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 9 ),
		)
	);

	// Testimonial number separator setting
	$wp_customize->add_setting(
		'franchise_testimonial_num_separator',
		array(
			'sanitize_callback' => 'franchise_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Franchise_Separator_Custom_Control( 
		$wp_customize,
		'franchise_testimonial_num_separator',
			array(
				'section'		=> 'franchise_testimonial',
				'active_callback' => 'franchise_if_testimonial_not_disabled',
				'type'			=> 'franchise-separator',
			)
		)
	);

	// Testimonial category setting
	$wp_customize->add_setting(
		'franchise_testimonial_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'franchise_testimonial_cat',
		array(
			'section'		=> 'franchise_testimonial',
			'label'			=> esc_html__( 'Category:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_testimonial_cat',
			'type'			=> 'select',
			'choices'		=> franchise_get_post_cat_choices(),
		)
	);

	$testimonial_num = get_theme_mod( 'franchise_testimonial_num', 3 );
	for ( $i=1; $i <= $testimonial_num; $i++ ) { 
		// Testimonial custom image setting
		$wp_customize->add_setting(
			'franchise_testimonial_image_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_image',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'franchise_testimonial_image_' . $i,
				array(
					'section'		=> 'franchise_testimonial',
					'label'			=> esc_html__( 'Image ', 'franchise-pro' ) . $i,
					'active_callback' => 'franchise_if_testimonial_custom',
				)
			)
		);

		// Testimonial custom name setting
		$wp_customize->add_setting(
			'franchise_testimonial_custom_name_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_testimonial_custom_name'],
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_custom_name_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Title ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_testimonial_custom'
			)
		);

		// Testimonial custom sub title setting
		$wp_customize->add_setting(
			'franchise_testimonial_custom_sub_title_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['franchise_testimonial_custom_sub_title'],
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_custom_sub_title_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Sub title ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_testimonial_not_disabled'
			)
		);

	    // Testimonial custom content setting
		$wp_customize->add_setting(
			'franchise_testimonial_custom_content_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
				'default' => $default['franchise_testimonial_custom_content'],
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_custom_content_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Content ', 'franchise-pro' ) . $i,
				'description'			=> esc_html__( 'HTML Allowed ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_testimonial_custom',
				'type'			=> 'textarea'
			)
		);

		// Testimonial post setting
		$wp_customize->add_setting(
			'franchise_testimonial_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_post_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Post ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_testimonial_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);

		// Testimonial page setting
		$wp_customize->add_setting(
			'franchise_testimonial_page_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'franchise_testimonial_page_' . $i,
			array(
				'section'		=> 'franchise_testimonial',
				'label'			=> esc_html__( 'Page ', 'franchise-pro' ) . $i,
				'type'			=> 'dropdown-pages',
				'active_callback' => 'franchise_if_testimonial_page'
			)
		);

		// Testimonial custom separator setting
		$wp_customize->add_setting(
			'franchise_testimonial_custom_separator_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Franchise_Separator_Custom_Control( 
			$wp_customize,
			'franchise_testimonial_custom_separator_' . $i,
				array(
					'section'		=> 'franchise_testimonial',
					'active_callback' => 'franchise_if_testimonial_not_disabled',
					'type'			=> 'franchise-separator',
				)
			)
		);
	}

	/**
	 * Partner section
	 */
	// Partner section
	$wp_customize->add_section(
		'franchise_partner',
		array(
			'title' => esc_html__( 'Partner', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Partner enable setting
	$wp_customize->add_setting(
		'franchise_enable_partner',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_partner',
		array(
			'section'		=> 'franchise_partner',
			'label'			=> esc_html__( 'Enable partner.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Partner title setting
	$wp_customize->add_setting(
		'franchise_partner_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Our Clients', 'franchise-pro' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_partner_title',
		array(
			'section'		=> 'franchise_partner',
			'label'			=> esc_html__( 'Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_partner_enable'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_partner_title', 
		array(
	        'selector'            => '#partners-logo .section-subtitle',
			'render_callback'     => 'franchise_partner_partial_title',
    	) 
    );

	// Partner number setting
	$wp_customize->add_setting(
		'franchise_partner_num',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 4,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_partner_num',
		array(
			'section'		=> 'franchise_partner',
			'label'			=> esc_html__( 'Number of partners:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 10', 'franchise-pro' ),
			'active_callback' => 'franchise_if_partner_enable',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 10 ),
		)
	);

	$partner_num = get_theme_mod( 'franchise_partner_num', 4 );
	for ( $i=1; $i <= $partner_num; $i++ ) { 
		// Slider custom image setting
		$wp_customize->add_setting(
			'franchise_partner_logo_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_image',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'franchise_partner_logo_' . $i,
				array(
					'section'		=> 'franchise_partner',
					'label'			=> esc_html__( 'Partner logo ', 'franchise-pro' ) . $i,
					'active_callback' => 'franchise_if_partner_enable',
				)
			)
		);

		// Partner link setting
		$wp_customize->add_setting(
			'franchise_partner_link_' . $i,
			array(
				'sanitize_callback' => 'esc_url_raw',
				'default' => '#',
			)
		);

		$wp_customize->add_control(
			'franchise_partner_link_' . $i,
			array(
				'section'		=> 'franchise_partner',
				'label'			=> esc_html__( 'Partner link ', 'franchise-pro' ) . $i,
				'type'			=> 'url',
				'active_callback' => 'franchise_if_partner_enable'
			)
		);

		// Partner open in new tab settings
		$wp_customize->add_setting(
			'franchise_partner_open_new_tab_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_checkbox',
				'default' => true
			)
		);

		$wp_customize->add_control(
			'franchise_partner_open_new_tab_' . $i,
			array(
				'section'		=> 'franchise_partner',
				'label'			=> esc_html__( 'Open in new tab.', 'franchise-pro' ),
				'type'			=> 'checkbox',
				'active_callback' => 'franchise_if_partner_enable'
			)
		);

		// Partner separator setting
		$wp_customize->add_setting(
			'franchise_partner_separator_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Franchise_Separator_Custom_Control( 
			$wp_customize,
			'franchise_partner_separator_' . $i,
				array(
					'section'		=> 'franchise_partner',
					'active_callback' => 'franchise_if_partner_enable',
					'type'			=> 'franchise-separator',
				)
			)
		);
	}

	/**
	 * Blog section section
	 */
	// Blog section section
	$wp_customize->add_section(
		'franchise_blog_section',
		array(
			'title' => esc_html__( 'Blog section', 'franchise-pro' ),
			'panel' => 'franchise_home_panel',
		)
	);

	// Blog section enable settings
	$wp_customize->add_setting(
		'franchise_blog_section',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'recent-posts'
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'franchise-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
					'recent-posts' => esc_html__( 'Recent Posts', 'franchise-pro' ),
					'cat' => esc_html__( 'Category', 'franchise-pro' ),
					'post' => esc_html__( 'Post', 'franchise-pro' ),
			 	)
		)
	);

	// Blog section image position option.
	$wp_customize->add_setting(	
		'franchise_blog_image_position',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'before-title',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_image_position',
		array(
			'section'		=> 'franchise_blog_section',
			'type'			=> 'radio',
			'active_callback' => 'franchise_if_blog_section_not_disabled',
			'label'			=> esc_html__( 'Image position', 'franchise-pro' ),
			'choices'		=> array( 
									'after-title' => esc_html__( 'After title', 'franchise-pro' ), 
									'before-title' => esc_html__( 'Before title', 'franchise-pro' ), 
								),
		)
	);

	// Blog section title setting
	$wp_customize->add_setting(
		'franchise_blog_section_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_blog_section_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section_title',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_blog_section_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_blog_section_title', 
		array(
	        'selector'            => '#latest-posts .section-title',
			'render_callback'     => 'franchise_blog_section_partial_title',
    	) 
    );

    // Blog section sub title setting
	$wp_customize->add_setting(
		'franchise_blog_section_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['franchise_blog_section_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section_sub_title',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Sub Title:', 'franchise-pro' ),
			'active_callback' => 'franchise_if_blog_section_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_blog_section_sub_title', 
		array(
	        'selector'            => '#latest-posts .section-subtitle',
			'render_callback'     => 'franchise_blog_section_partial_sub_title',
    	) 
    );

    // Blog section number setting
	$wp_customize->add_setting(
		'franchise_blog_section_num',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 3,
			// 'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section_num',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Number of posts:', 'franchise-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 6', 'franchise-pro' ),
			'active_callback' => 'franchise_if_blog_section_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 6 ),
		)
	);

	// Blog section category setting
	$wp_customize->add_setting(
		'franchise_blog_section_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'franchise_blog_section_cat',
		array(
			'section'		=> 'franchise_blog_section',
			'label'			=> esc_html__( 'Category:', 'franchise-pro' ),
			'description'			=> esc_html__( 'The button will be linked to the selected category\'s archive link automatically.', 'franchise-pro' ),
			'active_callback' => 'franchise_if_blog_section_cat',
			'type'			=> 'select',
			'choices'		=> franchise_get_post_cat_choices(),
		)
	);

	$franchise_blog_section_num = get_theme_mod( 'franchise_blog_section_num', 3 );
	for ( $i=1; $i <= $franchise_blog_section_num; $i++ ) { 
		// Projects post setting
		$wp_customize->add_setting(
			'franchise_blog_section_post_' . $i,
			array(
				'sanitize_callback' => 'franchise_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'franchise_blog_section_post_' . $i,
			array(
				'section'		=> 'franchise_blog_section',
				'label'			=> esc_html__( 'Post ', 'franchise-pro' ) . $i,
				'active_callback' => 'franchise_if_blog_section_post',
				'type'			=> 'select',
				'choices'		=> franchise_get_post_choices(),
			)
		);
	}

	/**
	 *
	 * General settings panel
	 * 
	 */
	// General settings panel
	$wp_customize->add_panel(
		'franchise_general_panel',
		array(
			'title' => esc_html__( 'Advanced Settings', 'franchise-pro' ),
			'priority' => 107
		)
	);

	$wp_customize->get_section( 'colors' )->panel         = 'franchise_general_panel';
	
	// Header title color setting
	$wp_customize->add_setting(	
		'franchise_header_title_color',
		array(
			'sanitize_callback' => 'franchise_sanitize_hex_color',
			'default' => '#ff8737',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'franchise_header_title_color',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site title Color:', 'franchise-pro' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'franchise_header_tagline',
		array(
			'sanitize_callback' => 'franchise_sanitize_hex_color',
			'default' => '#929292',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'franchise_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'franchise-pro' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'franchise_header_color_scheme',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'white',
		)
	);

	$wp_customize->add_control( 'franchise_header_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio',
			'label'			=> esc_html__( 'Header color scheme:', 'franchise-pro' ),
			'choices'			=> array( 
				'white' => esc_html__( 'White', 'franchise-pro' ), 
				'black' => esc_html__( 'Black', 'franchise-pro' ), 
			),
		)
	);
	
	// Color scheme setting
	$wp_customize->add_setting(	
		'franchise_color_scheme',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default'	=> 'default',
		)
	);

	$wp_customize->add_control( 
		new Franchise_Customize_Control_Radio_Color( 
		$wp_customize,
		'franchise_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio-color',
			'label'			=> esc_html__( 'Color scheme:', 'franchise-pro' ),
			'choices'		=> array( 
				'default' => array( 
					'color' => '#ff8737'
				),
				'blue' => array( 
					'color' => '#00b9ff'
				),
				'green' => array( 
					'color' => '#0cc652'
				),
				'red' => array( 
					'color' => '#E1222A'
				),
				'custom' => array( 
					'color' => '#E1222A'
				),
			),
		)
	)
	);

	// Custom color scheme scheme setting
	$wp_customize->add_setting(	
		'franchise_custom_color_scheme',
		array(
			'sanitize_callback' => 'franchise_sanitize_hex_color',
			'default' => '#ff8737',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'franchise_custom_color_scheme',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Custom color:', 'franchise-pro' ),
				'active_callback' => 'franchise_if_custom_color_scheme',
			)
		)
	);

	$wp_customize->get_section( 'background_image' )->panel         = 'franchise_general_panel';
	$wp_customize->get_section( 'custom_css' )->panel         = 'franchise_general_panel';

	/**
	 * General settings
	 */
	// General settings
	$wp_customize->add_section(
		'franchise_general_section',
		array(
			'title' => esc_html__( 'General', 'franchise-pro' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Enable smoothscroll setting
	$wp_customize->add_setting(
		'franchise_smoothscroll_enable',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'franchise_smoothscroll_enable',
		array(
			'section'		=> 'franchise_general_section',
			'label'			=> esc_html__( 'Enable smooth scroll.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Enable animation setting
	$wp_customize->add_setting(
		'franchise_animation_enable',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'franchise_animation_enable',
		array(
			'section'		=> 'franchise_general_section',
			'label'			=> esc_html__( 'Enable animation.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Breadcrumb enable setting
	$wp_customize->add_setting(
		'franchise_breadcrumb_enable',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_breadcrumb_enable',
		array(
			'section'		=> 'franchise_general_section',
			'label'			=> esc_html__( 'Enable breadcrumb.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Backtop enable setting
	$wp_customize->add_setting(
		'franchise_back_to_top_enable',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_back_to_top_enable',
		array(
			'section'		=> 'franchise_general_section',
			'label'			=> esc_html__( 'Enable Scroll up.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Global Layout
	 */
	// Global Layout
	$wp_customize->add_section(
		'franchise_global_layout',
		array(
			'title' => esc_html__( 'Global Layout', 'franchise-pro' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Global site layout setting
	$wp_customize->add_setting(
		'franchise_site_layout',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'wide',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_site_layout',
		array(
			'section'		=> 'franchise_global_layout',
			'label'			=> esc_html__( 'Site layout', 'franchise-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'boxed' => esc_html__( 'Boxed', 'franchise-pro' ), 
				'wide' => esc_html__( 'Wide', 'franchise-pro' ), 
				'frame' => esc_html__( 'Frame', 'franchise-pro' ), 
			),
		)
	);

	// Global archive layout setting
	$wp_customize->add_setting(
		'franchise_archive_sidebar',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'franchise_archive_sidebar',
		array(
			'section'		=> 'franchise_global_layout',
			'label'			=> esc_html__( 'Archive Sidebar', 'franchise-pro' ),
			'description'			=> esc_html__( 'This option works on all archive pages like: 404, search, date, category, "Your latest posts" and so on.', 'franchise-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'franchise-pro' ), 
				'right' => esc_html__( 'Right', 'franchise-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'franchise-pro' ), 
			),
		)
	);

	// Global page layout setting
	$wp_customize->add_setting(
		'franchise_global_page_layout',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'franchise_global_page_layout',
		array(
			'section'		=> 'franchise_global_layout',
			'label'			=> esc_html__( 'Global page sidebar', 'franchise-pro' ),
			'description'			=> esc_html__( 'This option works only on single pages including "Posts page". This setting can be overridden for single page from the metabox too.', 'franchise-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'franchise-pro' ), 
				'right' => esc_html__( 'Right', 'franchise-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'franchise-pro' ), 
			),
		)
	);

	// Global post layout setting
	$wp_customize->add_setting(
		'franchise_global_post_layout',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'franchise_global_post_layout',
		array(
			'section'		=> 'franchise_global_layout',
			'label'			=> esc_html__( 'Global post sidebar', 'franchise-pro' ),
			'description'			=> esc_html__( 'This option works only on single posts. This setting can be overridden for single post from the metabox too.', 'franchise-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'franchise-pro' ), 
				'right' => esc_html__( 'Right', 'franchise-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'franchise-pro' ), 
			),
		)
	);

	/**
	 * Blog/Archive section 
	 */
	// Blog/Archive section 
	$wp_customize->add_section(
		'franchise_archive_settings',
		array(
			'title' => esc_html__( 'Archive/Blog', 'franchise-pro' ),
			'description' => esc_html__( 'Settings for archive pages including blog page too.', 'franchise-pro' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Archive excerpt setting
	$wp_customize->add_setting(
		'franchise_archive_excerpt',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'View the post', 'franchise-pro' ),
		)
	);

	$wp_customize->add_control(
		'franchise_archive_excerpt',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Excerpt more text:', 'franchise-pro' ),
		)
	);

	// Archive excerpt length setting
	$wp_customize->add_setting(
		'franchise_archive_excerpt_length',
		array(
			'sanitize_callback' => 'franchise_sanitize_number_range',
			'default' => 60,
		)
	);

	$wp_customize->add_control(
		'franchise_archive_excerpt_length',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Excerpt more length:', 'franchise-pro' ),
			'type'			=> 'number',
			'input_attrs'   => array( 'min' => 5 ),
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'franchise_enable_archive_date',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_date',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Enable date.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'franchise_enable_archive_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_cat',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Enable category.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Tag enable setting
	$wp_customize->add_setting(
		'franchise_enable_archive_tag',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_tag',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Enable tags.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'franchise_enable_archive_comment',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_comment',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Enable comment count.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Author enable setting
	$wp_customize->add_setting(
		'franchise_enable_archive_author',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_author',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Enable author.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'franchise_enable_archive_featured_img',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_featured_img',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Content type setting
	$wp_customize->add_setting(
		'franchise_enable_archive_content_type',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'excerpt',
		)
	);

	$wp_customize->add_control(
		'franchise_enable_archive_content_type',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Content type:', 'franchise-pro' ),
			'choices'		=> array(
				'full-content' => esc_html__( 'Full content', 'franchise-pro' ), 
				'excerpt' => esc_html__( 'Excerpt', 'franchise-pro' ), 
			),
			'type'			=> 'radio',
		)
	);

	// Pagination type setting
	$wp_customize->add_setting(
		'franchise_archive_pagination_type',
		array(
			'sanitize_callback' => 'franchise_sanitize_select',
			'default' => 'numeric',
		)
	);

	$archive_pagination_description = '';
	$archive_pagination_choices = array( 
				'disable' => esc_html__( '--Disable--', 'franchise-pro' ),
				'numeric' => esc_html__( 'Numeric', 'franchise-pro' ),
				'older_newer' => esc_html__( 'Older / Newer', 'franchise-pro' ),
			);
	if ( ! class_exists( 'JetPack' ) ) {
		$archive_pagination_description = sprintf( esc_html__( 'We recommend to install %1$sJetpack%2$s and enable %3$sInfinite Scroll%4$s feature for automatic loading of posts.', 'franchise-pro' ), '<a target="_blank" href="http://wordpress.org/plugins/jetpack">', '</a>', '<b>', '</b>' );
	} else {
		$archive_pagination_choices['infinite_scroll'] = esc_html__( 'Infinite Load', 'franchise-pro' );
	}
	$wp_customize->add_control(
		'franchise_archive_pagination_type',
		array(
			'section'		=> 'franchise_archive_settings',
			'label'			=> esc_html__( 'Pagination type:', 'franchise-pro' ),
			'description'			=>  $archive_pagination_description,
			'type'			=> 'select',
			'choices'		=> $archive_pagination_choices,
		)
	);

	/**
	 * Single setting section 
	 */
	// Single setting section 
	$wp_customize->add_section(
		'franchise_single_settings',
		array(
			'title' => esc_html__( 'Single Posts', 'franchise-pro' ),
			'description' => esc_html__( 'Settings for all single posts.', 'franchise-pro' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_date',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_date',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable date.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_cat',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_cat',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable category.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Tag enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_tag',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_tag',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable tags.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_comment',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_comment',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable comment.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Author enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_author',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_author',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable author.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_featured_img',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_featured_img',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_pagination',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_pagination',
		array(
			'section'		=> 'franchise_single_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Single pages setting section 
	 */
	// Single pages setting section 
	$wp_customize->add_section(
		'franchise_single_page_settings',
		array(
			'title' => esc_html__( 'Single Pages', 'franchise-pro' ),
			'description' => esc_html__( 'Settings for all single pages.', 'franchise-pro' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Author enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_page_author',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_page_author',
		array(
			'section'		=> 'franchise_single_page_settings',
			'label'			=> esc_html__( 'Enable author.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_page_featured_img',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_page_featured_img',
		array(
			'section'		=> 'franchise_single_page_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'franchise_enable_single_page_pagination',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_single_page_pagination',
		array(
			'section'		=> 'franchise_single_page_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Reset all settings
	 */
	// Reset settings section
	$wp_customize->add_section(
		'franchise_reset_sections',
		array(
			'title' => esc_html__( 'Reset all', 'franchise-pro' ),
			'description' => esc_html__( 'Reset all settings to default.', 'franchise-pro' ),
			'panel' => 'franchise_general_panel',
		)
	);

	// Reset sortable order setting
	$wp_customize->add_setting(
		'franchise_reset_settings',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => false,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_reset_settings',
		array(
			'section'		=> 'franchise_reset_sections',
			'label'			=> esc_html__( 'Reset all settings?', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 *
	 *
	 * Footer copyright
	 *
	 *
	 */
	// Footer copyright
	$wp_customize->add_section(
		'franchise_footer_section',
		array(
			'title' => esc_html__( 'Footer', 'franchise-pro' ),
			'priority' => 106,
			// 'panel' => 'franchise_general_panel',
		)
	);

	// Footer social menu enable setting
	$wp_customize->add_setting(
		'franchise_enable_footer_social_menu',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_footer_social_menu',
		array(
			'section'		=> 'franchise_footer_section',
			'label'			=> esc_html__( 'Enable social menu.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer text enable setting
	$wp_customize->add_setting(
		'franchise_enable_footer_text',
		array(
			'sanitize_callback' => 'franchise_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'franchise_enable_footer_text',
		array(
			'section'		=> 'franchise_footer_section',
			'label'			=> esc_html__( 'Enable footer text.', 'franchise-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer copyright setting
	$wp_customize->add_setting(
		'franchise_copyright_txt',
		array(
			'sanitize_callback' => 'franchise_sanitize_html',
			'default' => $default['franchise_copyright_txt'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'franchise_copyright_txt',
		array(
			'section'		=> 'franchise_footer_section',
			'label'			=> esc_html__( 'Copyright text:', 'franchise-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'franchise_if_footer_text_enable',
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'franchise_copyright_txt', 
		array(
	        'selector'            => '#colophon .site-info .footer-copyright',
			'render_callback'     => 'franchise_copyright_partial',
    	) 
    );
}
add_action( 'customize_register', 'franchise_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function franchise_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function franchise_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function franchise_customize_preview_js() {
	wp_enqueue_script( 'franchise-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'franchise_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function franchise_customize_control_js() {


	wp_enqueue_style( 'franchise-customize-style', get_theme_file_uri( '/assets/css/customize-controls.css' ), array(), '20151215' );

	wp_enqueue_script( 'franchise-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'franchise-pro' ),
		'reset_msg' => esc_html__( 'Warning!!! This will reset all the settings. Refresh the page after Save and Publish to reset all.', 'franchise-pro' ),
	);

	wp_localize_script( 'franchise-customize-control', 'localized_data', $localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'franchise_customize_control_js' );

/**
 *
 * Sanitization callbacks.
 * 
 */

/**
 * Checkbox sanitization callback example.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function franchise_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}


/**
 * HEX Color sanitization callback example.
 *
 * - Sanitization: hex_color
 * - Control: text, WP_Customize_Color_Control
 *
 */
function franchise_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! is_null( $hex_color ) ? $hex_color : $setting->default );
}

/**
 * Image sanitization callback example.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 */
function franchise_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        'svg'          => 'image/svg+xml'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Select sanitization callback example.
 *
 * - Sanitization: select
 * - Control: select, radio
 */
function franchise_sanitize_select( $input, $setting ) {
	
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Drop-down Pages sanitization callback example.
 *
 * - Sanitization: dropdown-pages
 * - Control: dropdown-pages
 * 
 */
function franchise_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );
	
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 * 
 */
function franchise_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

/**
 * HTML sanitization callback example.
 *
 * - Sanitization: html
 * - Control: text, textarea
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function franchise_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

/**
 * Sortable section sanitization callback example.
 *
 * - Sanitization: sortable section
 * - Control: sortable
 *
 * @param string $input Value to be sanitized.
 * @return array Sanitized values as array.
 */
function franchise_sanitize_sort( $input ) {
	// Ensure $input is an array.
	if ( ! is_array( $input ) ){
		$input = explode( ',', $input );
	}

	$output = array_map( 'sanitize_text_field', $input );

	return $output;
}

/**
 *
 * Active callbacks.
 * 
 */

/**
 * Check if the about is enabled
 */
function franchise_if_about_enabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_about' )->value();
}

/**
 * Check if the about is custom
 */
function franchise_if_about_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'franchise_about' )->value();
}

/**
 * Check if the about is page
 */
function franchise_if_about_page( $control ) {
	return 'page' === $control->manager->get_setting( 'franchise_about' )->value();
}

/**
 * Check if the about is post
 */
function franchise_if_about_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_about' )->value();
}

/**
 * Check if the projects is not disabled
 */
function franchise_if_projects_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_projects' )->value();
}

/**
 * Check if the projects is page
 */
function franchise_if_projects_page( $control ) {
	return 'page' === $control->manager->get_setting( 'franchise_projects' )->value();
}

/**
 * Check if the projects is post
 */
function franchise_if_projects_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_projects' )->value();
}

/**
 * Check if the projects is cat
 */
function franchise_if_projects_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'franchise_projects' )->value();
}

/**
 * Check if the projects is custom
 */
function franchise_if_projects_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'franchise_projects' )->value();
}

/**
 * Check if the projects is not disabled or category.
 */
function franchise_if_projects_not_cat_disabled( $control ) {
	return ( ! franchise_if_projects_cat( $control ) && franchise_if_projects_not_disabled( $control ) );
}

/**
 * Check if the services is not disabled
 */
function franchise_if_services_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_services' )->value();
}

/**
 * Check if the services is page
 */
function franchise_if_services_page( $control ) {
	return 'page' === $control->manager->get_setting( 'franchise_services' )->value();
}

/**
 * Check if the services is post
 */
function franchise_if_services_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_services' )->value();
}

/**
 * Check if the services is cat
 */
function franchise_if_services_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'franchise_services' )->value();
}

/**
 * Check if the services is custom
 */
function franchise_if_services_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'franchise_services' )->value();
}

/**
 * Check if the services is not disabled or category.
 */
function franchise_if_services_not_cat_disabled( $control ) {
	return ( ! franchise_if_services_cat( $control ) && franchise_if_services_not_disabled( $control ) );
}

/**
 * Check if the testimonial is not disabled
 */
function franchise_if_testimonial_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_testimonial' )->value();
}

/**
 * Check if the testimonial is page
 */
function franchise_if_testimonial_page( $control ) {
	return 'page' === $control->manager->get_setting( 'franchise_testimonial' )->value();
}

/**
 * Check if the testimonial is post
 */
function franchise_if_testimonial_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_testimonial' )->value();
}

/**
 * Check if the testimonial is cat
 */
function franchise_if_testimonial_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'franchise_testimonial' )->value();
}

/**
 * Check if the testimonial is custom
 */
function franchise_if_testimonial_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'franchise_testimonial' )->value();
}

/**
 * Check if the slider is not disabled
 */
function franchise_if_slider_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_slider' )->value();
}

/**
 * Check if the slider is page
 */
function franchise_if_slider_page( $control ) {
	return 'page' === $control->manager->get_setting( 'franchise_slider' )->value();
}

/**
 * Check if the slider is post
 */
function franchise_if_slider_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_slider' )->value();
}

/**
 * Check if the slider is cat
 */
function franchise_if_slider_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'franchise_slider' )->value();
}

/**
 * Check if the slider is custom
 */
function franchise_if_slider_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'franchise_slider' )->value();
}

/**
 * Check if the partner is enabled.
 */
function franchise_if_partner_enable( $control ) {
	return $control->manager->get_setting( 'franchise_enable_partner' )->value();
}

/**
 * Check if the blog section is not disabled
 */
function franchise_if_blog_section_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'franchise_blog_section' )->value();
}

/**
 * Check if the blog section is cat
 */
function franchise_if_blog_section_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'franchise_blog_section' )->value();
}

/**
 * Check if the blog section is post
 */
function franchise_if_blog_section_post( $control ) {
	return 'post' === $control->manager->get_setting( 'franchise_blog_section' )->value();
}

/**
 * Check if the footer text is enabled
 */
function franchise_if_footer_text_enable( $control ) {
	return $control->manager->get_setting( 'franchise_enable_footer_text' )->value();
}

/**
 * Check if custom color scheme is enabled
 */
function franchise_if_custom_color_scheme( $control ) {
	return 'custom' === $control->manager->get_setting( 'franchise_color_scheme' )->value();
}

/**
 * Selective refresh.
 */

/**
 * Selective refresh for about title.
 */
function franchise_about_partial_title() {
	return esc_html( get_theme_mod( 'franchise_about_title' ) );
}

/**
 * Selective refresh for about sub title.
 */
function franchise_about_partial_sub_title() {
	return esc_html( get_theme_mod( 'franchise_about_sub_title' ) );
}

/**
 * Selective refresh for about content.
 */
function franchise_about_partial_content() {
	return wp_kses_post( get_theme_mod( 'franchise_about_content' ) );
}

/**
 * Selective refresh for about btn text.
 */
function franchise_about_partial_btn_txt() {
	return esc_html( get_theme_mod( 'franchise_about_btn_txt' ) );
}

/**
 * Selective refresh for projects title.
 */
function franchise_projects_partial_title() {
	return esc_html( get_theme_mod( 'franchise_projects_title' ) );
}

/**
 * Selective refresh for projects btn text.
 */
function franchise_projects_partial_sub_title() {
	return esc_html( get_theme_mod( 'franchise_projects_sub_title' ) );
}

/**
 * Selective refresh for blog section title.
 */
function franchise_blog_section_partial_title() {
	return esc_html( get_theme_mod( 'franchise_blog_section_title' ) );
}

/**
 * Selective refresh for blog section text.
 */
function franchise_blog_section_partial_sub_title() {
	return esc_html( get_theme_mod( 'franchise_blog_section_sub_title' ) );
}

/**
 * Selective refresh for footer copyright.
 */
function franchise_copyright_partial() {
	return wp_kses_post( get_theme_mod( 'franchise_copyright_txt' ) );
}

/**
 * Selective refresh for your latest posts title.
 */
function franchise_your_latest_posts_partial_title() {
	return esc_html( get_theme_mod( 'franchise_your_latest_posts_title' ) );
}

/**
 * Selective refresh for partner title.
 */
function franchise_partner_partial_title() {
	return esc_html( get_theme_mod( 'franchise_partner_title' ) );
}